@@ -1092,7 +1092,8 @@ module.exports = {
 	],
 	"87.0.4280.88": [
 		"11.0.5",
-		"11.1.0"
+		"11.1.0",
+		"11.1.1"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1104,6 +1105,8 @@ module.exports = {
 		"12.0.0-beta.8",
 		"12.0.0-beta.9",
 		"12.0.0-beta.10",
+		"12.0.0-beta.11",
+		"12.0.0-beta.12",
 		"13.0.0-nightly.20201119",
 		"13.0.0-nightly.20201123",
 		"13.0.0-nightly.20201124",
@@ -1142,5 +1145,15 @@ module.exports = {
 	],
 	"88.0.4324.0": [
 		"12.0.0-nightly.20201116"
+	],
+	"89.0.4349.0": [
+		"13.0.0-nightly.20201215",
+		"13.0.0-nightly.20201216",
+		"13.0.0-nightly.20201221",
+		"13.0.0-nightly.20201222"
+	],
+	"89.0.4359.0": [
+		"13.0.0-nightly.20201223",
+		"13.0.0-nightly.20210104"
 	]
 };
\ No newline at end of file
