@@ -762,6 +762,7 @@ module.exports = {
 	"11.0.4": "87.0.4280.67",
 	"11.0.5": "87.0.4280.88",
 	"11.1.0": "87.0.4280.88",
+	"11.1.1": "87.0.4280.88",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -771,6 +772,8 @@ module.exports = {
 	"12.0.0-beta.8": "89.0.4328.0",
 	"12.0.0-beta.9": "89.0.4328.0",
 	"12.0.0-beta.10": "89.0.4328.0",
+	"12.0.0-beta.11": "89.0.4328.0",
+	"12.0.0-beta.12": "89.0.4328.0",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -808,5 +811,11 @@ module.exports = {
 	"13.0.0-nightly.20201209": "89.0.4328.0",
 	"13.0.0-nightly.20201210": "89.0.4328.0",
 	"13.0.0-nightly.20201211": "89.0.4328.0",
-	"13.0.0-nightly.20201214": "89.0.4328.0"
+	"13.0.0-nightly.20201214": "89.0.4328.0",
+	"13.0.0-nightly.20201215": "89.0.4349.0",
+	"13.0.0-nightly.20201216": "89.0.4349.0",
+	"13.0.0-nightly.20201221": "89.0.4349.0",
+	"13.0.0-nightly.20201222": "89.0.4349.0",
+	"13.0.0-nightly.20201223": "89.0.4359.0",
+	"13.0.0-nightly.20210104": "89.0.4359.0"
 };
\ No newline at end of file
